"""
Exposes a mixin for each pachyderm service. These mixins should not be used
directly; instead, you should use `python_pachyderm.Client`. The mixins exist
exclusively in order to provide better code organization (because we have
several mixins, rather than one giant `Client` class.)
"""



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client/admin/v1_7/hashtree/hashtree.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from python_pachyderm.proto.admin.v1_7.pfs import pfs_pb2 as client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='client/admin/v1_7/hashtree/hashtree.proto',
  package='hashtree_1_7',
  syntax='proto3',
  serialized_options=b'Z=github.com/pachyderm/pachyderm/src/client/admin/v1_7/hashtree',
  serialized_pb=b'\n)client/admin/v1_7/hashtree/hashtree.proto\x12\x0chashtree_1_7\x1a\x1f\x63lient/admin/v1_7/pfs/pfs.proto\"1\n\rFileNodeProto\x12 \n\x07objects\x18\x04 \x03(\x0b\x32\x0f.pfs_1_7.Object\"h\n\x12\x44irectoryNodeProto\x12\x10\n\x08\x63hildren\x18\x03 \x03(\t\x12\x1f\n\x06header\x18\x04 \x01(\x0b\x32\x0f.pfs_1_7.Object\x12\x1f\n\x06\x66ooter\x18\x05 \x01(\x0b\x32\x0f.pfs_1_7.Object\"\xa1\x01\n\tNodeProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\x12\x14\n\x0csubtree_size\x18\x03 \x01(\x03\x12.\n\tfile_node\x18\x04 \x01(\x0b\x32\x1b.hashtree_1_7.FileNodeProto\x12\x32\n\x08\x64ir_node\x18\x05 \x01(\x0b\x32 .hashtree_1_7.DirectoryNodeProto\"\x95\x01\n\rHashTreeProto\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12/\n\x02\x66s\x18\x02 \x03(\x0b\x32#.hashtree_1_7.HashTreeProto.FsEntry\x1a\x42\n\x07\x46sEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.hashtree_1_7.NodeProto:\x02\x38\x01\x42?Z=github.com/pachyderm/pachyderm/src/client/admin/v1_7/hashtreeb\x06proto3'
  ,
  dependencies=[client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2.DESCRIPTOR,])




_FILENODEPROTO = _descriptor.Descriptor(
  name='FileNodeProto',
  full_name='hashtree_1_7.FileNodeProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='hashtree_1_7.FileNodeProto.objects', index=0,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=141,
)


_DIRECTORYNODEPROTO = _descriptor.Descriptor(
  name='DirectoryNodeProto',
  full_name='hashtree_1_7.DirectoryNodeProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='children', full_name='hashtree_1_7.DirectoryNodeProto.children', index=0,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='hashtree_1_7.DirectoryNodeProto.header', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer', full_name='hashtree_1_7.DirectoryNodeProto.footer', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=247,
)


_NODEPROTO = _descriptor.Descriptor(
  name='NodeProto',
  full_name='hashtree_1_7.NodeProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='hashtree_1_7.NodeProto.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='hashtree_1_7.NodeProto.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subtree_size', full_name='hashtree_1_7.NodeProto.subtree_size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_node', full_name='hashtree_1_7.NodeProto.file_node', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dir_node', full_name='hashtree_1_7.NodeProto.dir_node', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=411,
)


_HASHTREEPROTO_FSENTRY = _descriptor.Descriptor(
  name='FsEntry',
  full_name='hashtree_1_7.HashTreeProto.FsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hashtree_1_7.HashTreeProto.FsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='hashtree_1_7.HashTreeProto.FsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=563,
)

_HASHTREEPROTO = _descriptor.Descriptor(
  name='HashTreeProto',
  full_name='hashtree_1_7.HashTreeProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='hashtree_1_7.HashTreeProto.version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fs', full_name='hashtree_1_7.HashTreeProto.fs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HASHTREEPROTO_FSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=563,
)

_FILENODEPROTO.fields_by_name['objects'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._OBJECT
_DIRECTORYNODEPROTO.fields_by_name['header'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._OBJECT
_DIRECTORYNODEPROTO.fields_by_name['footer'].message_type = client_dot_admin_dot_v1__7_dot_pfs_dot_pfs__pb2._OBJECT
_NODEPROTO.fields_by_name['file_node'].message_type = _FILENODEPROTO
_NODEPROTO.fields_by_name['dir_node'].message_type = _DIRECTORYNODEPROTO
_HASHTREEPROTO_FSENTRY.fields_by_name['value'].message_type = _NODEPROTO
_HASHTREEPROTO_FSENTRY.containing_type = _HASHTREEPROTO
_HASHTREEPROTO.fields_by_name['fs'].message_type = _HASHTREEPROTO_FSENTRY
DESCRIPTOR.message_types_by_name['FileNodeProto'] = _FILENODEPROTO
DESCRIPTOR.message_types_by_name['DirectoryNodeProto'] = _DIRECTORYNODEPROTO
DESCRIPTOR.message_types_by_name['NodeProto'] = _NODEPROTO
DESCRIPTOR.message_types_by_name['HashTreeProto'] = _HASHTREEPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FileNodeProto = _reflection.GeneratedProtocolMessageType('FileNodeProto', (_message.Message,), {
  'DESCRIPTOR' : _FILENODEPROTO,
  '__module__' : 'client.admin.v1_7.hashtree.hashtree_pb2'
  # @@protoc_insertion_point(class_scope:hashtree_1_7.FileNodeProto)
  })
_sym_db.RegisterMessage(FileNodeProto)

DirectoryNodeProto = _reflection.GeneratedProtocolMessageType('DirectoryNodeProto', (_message.Message,), {
  'DESCRIPTOR' : _DIRECTORYNODEPROTO,
  '__module__' : 'client.admin.v1_7.hashtree.hashtree_pb2'
  # @@protoc_insertion_point(class_scope:hashtree_1_7.DirectoryNodeProto)
  })
_sym_db.RegisterMessage(DirectoryNodeProto)

NodeProto = _reflection.GeneratedProtocolMessageType('NodeProto', (_message.Message,), {
  'DESCRIPTOR' : _NODEPROTO,
  '__module__' : 'client.admin.v1_7.hashtree.hashtree_pb2'
  # @@protoc_insertion_point(class_scope:hashtree_1_7.NodeProto)
  })
_sym_db.RegisterMessage(NodeProto)

HashTreeProto = _reflection.GeneratedProtocolMessageType('HashTreeProto', (_message.Message,), {

  'FsEntry' : _reflection.GeneratedProtocolMessageType('FsEntry', (_message.Message,), {
    'DESCRIPTOR' : _HASHTREEPROTO_FSENTRY,
    '__module__' : 'client.admin.v1_7.hashtree.hashtree_pb2'
    # @@protoc_insertion_point(class_scope:hashtree_1_7.HashTreeProto.FsEntry)
    })
  ,
  'DESCRIPTOR' : _HASHTREEPROTO,
  '__module__' : 'client.admin.v1_7.hashtree.hashtree_pb2'
  # @@protoc_insertion_point(class_scope:hashtree_1_7.HashTreeProto)
  })
_sym_db.RegisterMessage(HashTreeProto)
_sym_db.RegisterMessage(HashTreeProto.FsEntry)


DESCRIPTOR._options = None
_HASHTREEPROTO_FSENTRY._options = None
# @@protoc_insertion_point(module_scope)



import os
import time
import string
import random

import pytest
import python_pachyderm

_test_pachyderm_version = None


def test_pachyderm_version():
    global _test_pachyderm_version

    if _test_pachyderm_version is None:
        value = os.environ.get("PACHYDERM_VERSION")

        if value is None:
            client = python_pachyderm.Client()
            value = client.get_remote_version()
            _test_pachyderm_version = (value.major, value.minor, value.micro)
        else:
            _test_pachyderm_version = tuple(int(i) for i in value.split("."))

    return _test_pachyderm_version


def skip_if_below_pachyderm_version(major, minor, revision):
    test = test_pachyderm_version() < (major, minor, revision)
    reason = "requires pachyderm {}.{}.{} or higher".format(major, minor, revision)
    return pytest.mark.skipif(test, reason=reason)


def skip_if_no_enterprise():
    test = os.environ.get("PACH_PYTHON_ENTERPRISE_CODE") == None
    return pytest.mark.skipif(test, reason="enterprise code not available")


def random_string(n):
    return "".join(
        random.choice(string.ascii_lowercase + string.digits) for _ in range(n)
    )


def test_repo_name(test_name, prefix=None, suffix=None):
    prefix = "" if prefix is None else "{}-".format(prefix)
    suffix = suffix or random_string(6)
    return "{}{}-{}".format(prefix, test_name, suffix)


def create_test_repo(client, test_name, prefix=None, suffix=None):
    repo_name = test_repo_name(test_name, prefix=prefix, suffix=suffix)
    client.create_repo(repo_name, "python_pachyderm test repo for {}".format(test_name))
    return repo_name


def create_test_pipeline(client, test_name):
    repo_name_suffix = random_string(6)
    input_repo_name = create_test_repo(
        client, test_name, prefix="input", suffix=repo_name_suffix
    )
    pipeline_repo_name = test_repo_name(
        test_name, prefix="pipeline", suffix=repo_name_suffix
    )

    client.create_pipeline(
        pipeline_repo_name,
        transform=python_pachyderm.Transform(
            cmd=["sh"],
            image="alpine",
            stdin=["cp /pfs/{}/*.dat /pfs/out/".format(input_repo_name)],
        ),
        input=python_pachyderm.Input(
            pfs=python_pachyderm.PFSInput(glob="/*", repo=input_repo_name)
        ),
        enable_stats=True,
    )

    with client.commit(input_repo_name, "master") as commit:
        client.put_file_bytes(commit, "file.dat", b"DATA")

    return (commit, input_repo_name, pipeline_repo_name)


def wait_for_job(client, commit):
    # block until the commit is ready
    client.inspect_commit(commit, block_state=python_pachyderm.CommitState.READY.value)

    # while the commit is ready, the job might not be listed on the first
    # call, so repeatedly list jobs until it's available
    start_time = time.time()
    while True:
        for job in client.list_job():
            return job.job.id

        assert time.time() - start_time < 60.0, "timed out waiting for job"
        time.sleep(1)


def get_cluster_deployment_id():
    client = python_pachyderm.Client()
    cluster_info = client.inspect_cluster()
    return cluster_info.deployment_id



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from python_pachyderm.proto.admin.v1_8.pfs import pfs_pb2 as client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


class APIStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateRepo = channel.unary_unary(
        '/pfs_1_8.API/CreateRepo',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CreateRepoRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.InspectRepo = channel.unary_unary(
        '/pfs_1_8.API/InspectRepo',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.InspectRepoRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.RepoInfo.FromString,
        )
    self.ListRepo = channel.unary_unary(
        '/pfs_1_8.API/ListRepo',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListRepoRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListRepoResponse.FromString,
        )
    self.DeleteRepo = channel.unary_unary(
        '/pfs_1_8.API/DeleteRepo',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteRepoRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.StartCommit = channel.unary_unary(
        '/pfs_1_8.API/StartCommit',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.StartCommitRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Commit.FromString,
        )
    self.FinishCommit = channel.unary_unary(
        '/pfs_1_8.API/FinishCommit',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FinishCommitRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.InspectCommit = channel.unary_unary(
        '/pfs_1_8.API/InspectCommit',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.InspectCommitRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
        )
    self.ListCommit = channel.unary_unary(
        '/pfs_1_8.API/ListCommit',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListCommitRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CommitInfos.FromString,
        )
    self.ListCommitStream = channel.unary_stream(
        '/pfs_1_8.API/ListCommitStream',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListCommitRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
        )
    self.DeleteCommit = channel.unary_unary(
        '/pfs_1_8.API/DeleteCommit',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteCommitRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.FlushCommit = channel.unary_stream(
        '/pfs_1_8.API/FlushCommit',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FlushCommitRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
        )
    self.SubscribeCommit = channel.unary_stream(
        '/pfs_1_8.API/SubscribeCommit',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.SubscribeCommitRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CommitInfo.FromString,
        )
    self.BuildCommit = channel.unary_unary(
        '/pfs_1_8.API/BuildCommit',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.BuildCommitRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Commit.FromString,
        )
    self.CreateBranch = channel.unary_unary(
        '/pfs_1_8.API/CreateBranch',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CreateBranchRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.InspectBranch = channel.unary_unary(
        '/pfs_1_8.API/InspectBranch',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.InspectBranchRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.BranchInfo.FromString,
        )
    self.ListBranch = channel.unary_unary(
        '/pfs_1_8.API/ListBranch',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListBranchRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.BranchInfos.FromString,
        )
    self.DeleteBranch = channel.unary_unary(
        '/pfs_1_8.API/DeleteBranch',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteBranchRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.PutFile = channel.stream_unary(
        '/pfs_1_8.API/PutFile',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.PutFileRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.CopyFile = channel.unary_unary(
        '/pfs_1_8.API/CopyFile',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CopyFileRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.GetFile = channel.unary_stream(
        '/pfs_1_8.API/GetFile',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.GetFileRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
        )
    self.InspectFile = channel.unary_unary(
        '/pfs_1_8.API/InspectFile',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.InspectFileRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
        )
    self.ListFile = channel.unary_unary(
        '/pfs_1_8.API/ListFile',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListFileRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfos.FromString,
        )
    self.ListFileStream = channel.unary_stream(
        '/pfs_1_8.API/ListFileStream',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListFileRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
        )
    self.WalkFile = channel.unary_stream(
        '/pfs_1_8.API/WalkFile',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.WalkFileRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
        )
    self.GlobFile = channel.unary_unary(
        '/pfs_1_8.API/GlobFile',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.GlobFileRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfos.FromString,
        )
    self.GlobFileStream = channel.unary_stream(
        '/pfs_1_8.API/GlobFileStream',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.GlobFileRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfo.FromString,
        )
    self.DiffFile = channel.unary_unary(
        '/pfs_1_8.API/DiffFile',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DiffFileRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DiffFileResponse.FromString,
        )
    self.DeleteFile = channel.unary_unary(
        '/pfs_1_8.API/DeleteFile',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteFileRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.DeleteAll = channel.unary_unary(
        '/pfs_1_8.API/DeleteAll',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class APIServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateRepo(self, request, context):
    """Repo rpcs
    CreateRepo creates a new repo.
    An error is returned if the repo already exists.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InspectRepo(self, request, context):
    """InspectRepo returns info about a repo.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListRepo(self, request, context):
    """ListRepo returns info about all repos.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteRepo(self, request, context):
    """DeleteRepo deletes a repo.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StartCommit(self, request, context):
    """Commit rpcs
    StartCommit creates a new write commit from a parent commit.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FinishCommit(self, request, context):
    """FinishCommit turns a write commit into a read commit.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InspectCommit(self, request, context):
    """InspectCommit returns the info about a commit.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListCommit(self, request, context):
    """ListCommit returns info about all commits. This is deprecated in favor of
    ListCommitStream.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListCommitStream(self, request, context):
    """ListCommitStream is like ListCommit, but returns its results in a GRPC stream
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteCommit(self, request, context):
    """DeleteCommit deletes a commit.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FlushCommit(self, request, context):
    """FlushCommit waits for downstream commits to finish
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SubscribeCommit(self, request, context):
    """SubscribeCommit subscribes for new commits on a given branch
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BuildCommit(self, request, context):
    """BuildCommit builds a commit that's backed by the given tree
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateBranch(self, request, context):
    """CreateBranch creates a new branch
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InspectBranch(self, request, context):
    """InspectBranch returns info about a branch.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListBranch(self, request, context):
    """ListBranch returns info about the heads of branches.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteBranch(self, request, context):
    """DeleteBranch deletes a branch; note that the commits still exist.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PutFile(self, request_iterator, context):
    """File rpcs
    PutFile writes the specified file to pfs.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CopyFile(self, request, context):
    """CopyFile copies the contents of one file to another.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetFile(self, request, context):
    """GetFile returns a byte stream of the contents of the file.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InspectFile(self, request, context):
    """InspectFile returns info about a file.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListFile(self, request, context):
    """ListFile returns info about all files. This is deprecated in favor of
    ListFileStream
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListFileStream(self, request, context):
    """ListFileStream is a streaming version of ListFile
    TODO(msteffen): When the dash has been updated to use ListFileStream,
    replace ListFile with this RPC (https://github.com/pachyderm/dash/issues/201)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WalkFile(self, request, context):
    """WalkFile walks over all the files under a directory, including children of children.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GlobFile(self, request, context):
    """GlobFile returns info about all files. This is deprecated in favor of
    GlobFileStream
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GlobFileStream(self, request, context):
    """GlobFileStream is a streaming version of GlobFile
    TODO(msteffen): When the dash has been updated to use GlobFileStream,
    replace GlobFile with this RPC (https://github.com/pachyderm/dash/issues/201)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DiffFile(self, request, context):
    """DiffFile returns the differences between 2 paths at 2 commits.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteFile(self, request, context):
    """DeleteFile deletes a file.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAll(self, request, context):
    """DeleteAll deletes everything
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_APIServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateRepo': grpc.unary_unary_rpc_method_handler(
          servicer.CreateRepo,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CreateRepoRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'InspectRepo': grpc.unary_unary_rpc_method_handler(
          servicer.InspectRepo,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.InspectRepoRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.RepoInfo.SerializeToString,
      ),
      'ListRepo': grpc.unary_unary_rpc_method_handler(
          servicer.ListRepo,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListRepoRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListRepoResponse.SerializeToString,
      ),
      'DeleteRepo': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteRepo,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteRepoRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'StartCommit': grpc.unary_unary_rpc_method_handler(
          servicer.StartCommit,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.StartCommitRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Commit.SerializeToString,
      ),
      'FinishCommit': grpc.unary_unary_rpc_method_handler(
          servicer.FinishCommit,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FinishCommitRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'InspectCommit': grpc.unary_unary_rpc_method_handler(
          servicer.InspectCommit,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.InspectCommitRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CommitInfo.SerializeToString,
      ),
      'ListCommit': grpc.unary_unary_rpc_method_handler(
          servicer.ListCommit,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListCommitRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CommitInfos.SerializeToString,
      ),
      'ListCommitStream': grpc.unary_stream_rpc_method_handler(
          servicer.ListCommitStream,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListCommitRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CommitInfo.SerializeToString,
      ),
      'DeleteCommit': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteCommit,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteCommitRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'FlushCommit': grpc.unary_stream_rpc_method_handler(
          servicer.FlushCommit,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FlushCommitRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CommitInfo.SerializeToString,
      ),
      'SubscribeCommit': grpc.unary_stream_rpc_method_handler(
          servicer.SubscribeCommit,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.SubscribeCommitRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CommitInfo.SerializeToString,
      ),
      'BuildCommit': grpc.unary_unary_rpc_method_handler(
          servicer.BuildCommit,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.BuildCommitRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Commit.SerializeToString,
      ),
      'CreateBranch': grpc.unary_unary_rpc_method_handler(
          servicer.CreateBranch,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CreateBranchRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'InspectBranch': grpc.unary_unary_rpc_method_handler(
          servicer.InspectBranch,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.InspectBranchRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.BranchInfo.SerializeToString,
      ),
      'ListBranch': grpc.unary_unary_rpc_method_handler(
          servicer.ListBranch,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListBranchRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.BranchInfos.SerializeToString,
      ),
      'DeleteBranch': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteBranch,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteBranchRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'PutFile': grpc.stream_unary_rpc_method_handler(
          servicer.PutFile,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.PutFileRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'CopyFile': grpc.unary_unary_rpc_method_handler(
          servicer.CopyFile,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CopyFileRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'GetFile': grpc.unary_stream_rpc_method_handler(
          servicer.GetFile,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.GetFileRequest.FromString,
          response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
      ),
      'InspectFile': grpc.unary_unary_rpc_method_handler(
          servicer.InspectFile,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.InspectFileRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfo.SerializeToString,
      ),
      'ListFile': grpc.unary_unary_rpc_method_handler(
          servicer.ListFile,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListFileRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfos.SerializeToString,
      ),
      'ListFileStream': grpc.unary_stream_rpc_method_handler(
          servicer.ListFileStream,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListFileRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfo.SerializeToString,
      ),
      'WalkFile': grpc.unary_stream_rpc_method_handler(
          servicer.WalkFile,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.WalkFileRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfo.SerializeToString,
      ),
      'GlobFile': grpc.unary_unary_rpc_method_handler(
          servicer.GlobFile,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.GlobFileRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfos.SerializeToString,
      ),
      'GlobFileStream': grpc.unary_stream_rpc_method_handler(
          servicer.GlobFileStream,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.GlobFileRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.FileInfo.SerializeToString,
      ),
      'DiffFile': grpc.unary_unary_rpc_method_handler(
          servicer.DiffFile,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DiffFileRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DiffFileResponse.SerializeToString,
      ),
      'DeleteFile': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteFile,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteFileRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'DeleteAll': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAll,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'pfs_1_8.API', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))


class ObjectAPIStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.PutObject = channel.stream_unary(
        '/pfs_1_8.ObjectAPI/PutObject',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.PutObjectRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Object.FromString,
        )
    self.PutObjectSplit = channel.stream_unary(
        '/pfs_1_8.ObjectAPI/PutObjectSplit',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.PutObjectRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Objects.FromString,
        )
    self.PutObjects = channel.stream_unary(
        '/pfs_1_8.ObjectAPI/PutObjects',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.PutObjectRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.GetObject = channel.unary_stream(
        '/pfs_1_8.ObjectAPI/GetObject',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Object.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
        )
    self.GetObjects = channel.unary_stream(
        '/pfs_1_8.ObjectAPI/GetObjects',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.GetObjectsRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
        )
    self.GetBlocks = channel.unary_stream(
        '/pfs_1_8.ObjectAPI/GetBlocks',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.GetBlocksRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
        )
    self.TagObject = channel.unary_unary(
        '/pfs_1_8.ObjectAPI/TagObject',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.TagObjectRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.InspectObject = channel.unary_unary(
        '/pfs_1_8.ObjectAPI/InspectObject',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Object.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ObjectInfo.FromString,
        )
    self.CheckObject = channel.unary_unary(
        '/pfs_1_8.ObjectAPI/CheckObject',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CheckObjectRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CheckObjectResponse.FromString,
        )
    self.ListObjects = channel.unary_stream(
        '/pfs_1_8.ObjectAPI/ListObjects',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListObjectsRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Object.FromString,
        )
    self.DeleteObjects = channel.unary_unary(
        '/pfs_1_8.ObjectAPI/DeleteObjects',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteObjectsRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteObjectsResponse.FromString,
        )
    self.GetTag = channel.unary_stream(
        '/pfs_1_8.ObjectAPI/GetTag',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Tag.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
        )
    self.InspectTag = channel.unary_unary(
        '/pfs_1_8.ObjectAPI/InspectTag',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Tag.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ObjectInfo.FromString,
        )
    self.ListTags = channel.unary_stream(
        '/pfs_1_8.ObjectAPI/ListTags',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListTagsRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListTagsResponse.FromString,
        )
    self.DeleteTags = channel.unary_unary(
        '/pfs_1_8.ObjectAPI/DeleteTags',
        request_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteTagsRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteTagsResponse.FromString,
        )
    self.Compact = channel.unary_unary(
        '/pfs_1_8.ObjectAPI/Compact',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class ObjectAPIServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def PutObject(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PutObjectSplit(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PutObjects(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetObject(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetObjects(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetBlocks(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def TagObject(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InspectObject(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CheckObject(self, request, context):
    """CheckObject checks if an object exists in the blob store without
    actually reading the object.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListObjects(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteObjects(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetTag(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InspectTag(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListTags(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteTags(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Compact(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ObjectAPIServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'PutObject': grpc.stream_unary_rpc_method_handler(
          servicer.PutObject,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.PutObjectRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Object.SerializeToString,
      ),
      'PutObjectSplit': grpc.stream_unary_rpc_method_handler(
          servicer.PutObjectSplit,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.PutObjectRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Objects.SerializeToString,
      ),
      'PutObjects': grpc.stream_unary_rpc_method_handler(
          servicer.PutObjects,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.PutObjectRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'GetObject': grpc.unary_stream_rpc_method_handler(
          servicer.GetObject,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Object.FromString,
          response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
      ),
      'GetObjects': grpc.unary_stream_rpc_method_handler(
          servicer.GetObjects,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.GetObjectsRequest.FromString,
          response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
      ),
      'GetBlocks': grpc.unary_stream_rpc_method_handler(
          servicer.GetBlocks,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.GetBlocksRequest.FromString,
          response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
      ),
      'TagObject': grpc.unary_unary_rpc_method_handler(
          servicer.TagObject,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.TagObjectRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'InspectObject': grpc.unary_unary_rpc_method_handler(
          servicer.InspectObject,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Object.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ObjectInfo.SerializeToString,
      ),
      'CheckObject': grpc.unary_unary_rpc_method_handler(
          servicer.CheckObject,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CheckObjectRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.CheckObjectResponse.SerializeToString,
      ),
      'ListObjects': grpc.unary_stream_rpc_method_handler(
          servicer.ListObjects,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListObjectsRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Object.SerializeToString,
      ),
      'DeleteObjects': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteObjects,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteObjectsRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteObjectsResponse.SerializeToString,
      ),
      'GetTag': grpc.unary_stream_rpc_method_handler(
          servicer.GetTag,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Tag.FromString,
          response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
      ),
      'InspectTag': grpc.unary_unary_rpc_method_handler(
          servicer.InspectTag,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.Tag.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ObjectInfo.SerializeToString,
      ),
      'ListTags': grpc.unary_stream_rpc_method_handler(
          servicer.ListTags,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListTagsRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.ListTagsResponse.SerializeToString,
      ),
      'DeleteTags': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteTags,
          request_deserializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteTagsRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__8_dot_pfs_dot_pfs__pb2.DeleteTagsResponse.SerializeToString,
      ),
      'Compact': grpc.unary_unary_rpc_method_handler(
          servicer.Compact,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'pfs_1_8.ObjectAPI', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client/transaction/transaction.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from python_pachyderm.proto.pfs import pfs_pb2 as client_dot_pfs_dot_pfs__pb2
from python_pachyderm.proto.pps import pps_pb2 as client_dot_pps_dot_pps__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='client/transaction/transaction.proto',
  package='transaction',
  syntax='proto3',
  serialized_options=b'Z5github.com/pachyderm/pachyderm/src/client/transaction',
  serialized_pb=b'\n$client/transaction/transaction.proto\x12\x0btransaction\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14\x63lient/pfs/pfs.proto\x1a\x14\x63lient/pps/pps.proto\"\x12\n\x10\x44\x65leteAllRequest\"\xff\x03\n\x12TransactionRequest\x12+\n\x0b\x63reate_repo\x18\x01 \x01(\x0b\x32\x16.pfs.CreateRepoRequest\x12+\n\x0b\x64\x65lete_repo\x18\x02 \x01(\x0b\x32\x16.pfs.DeleteRepoRequest\x12-\n\x0cstart_commit\x18\x03 \x01(\x0b\x32\x17.pfs.StartCommitRequest\x12/\n\rfinish_commit\x18\x04 \x01(\x0b\x32\x18.pfs.FinishCommitRequest\x12/\n\rdelete_commit\x18\x05 \x01(\x0b\x32\x18.pfs.DeleteCommitRequest\x12/\n\rcreate_branch\x18\x06 \x01(\x0b\x32\x18.pfs.CreateBranchRequest\x12/\n\rdelete_branch\x18\x07 \x01(\x0b\x32\x18.pfs.DeleteBranchRequest\x12\x34\n\x10update_job_state\x18\x0b \x01(\x0b\x32\x1a.pps.UpdateJobStateRequest\x12\x33\n\x0f\x63reate_pipeline\x18\x0c \x01(\x0b\x32\x1a.pps.CreatePipelineRequest\x12\x31\n\ndelete_all\x18\n \x01(\x0b\x32\x1d.transaction.DeleteAllRequest\"2\n\x13TransactionResponse\x12\x1b\n\x06\x63ommit\x18\x02 \x01(\x0b\x32\x0b.pfs.Commit\"\x19\n\x0bTransaction\x12\n\n\x02id\x18\x01 \x01(\t\"\xd5\x01\n\x0fTransactionInfo\x12-\n\x0btransaction\x18\x01 \x01(\x0b\x32\x18.transaction.Transaction\x12\x31\n\x08requests\x18\x02 \x03(\x0b\x32\x1f.transaction.TransactionRequest\x12\x33\n\tresponses\x18\x03 \x03(\x0b\x32 .transaction.TransactionResponse\x12+\n\x07started\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"J\n\x10TransactionInfos\x12\x36\n\x10transaction_info\x18\x01 \x03(\x0b\x32\x1c.transaction.TransactionInfo\"L\n\x17\x42\x61tchTransactionRequest\x12\x31\n\x08requests\x18\x01 \x03(\x0b\x32\x1f.transaction.TransactionRequest\"\x19\n\x17StartTransactionRequest\"J\n\x19InspectTransactionRequest\x12-\n\x0btransaction\x18\x01 \x01(\x0b\x32\x18.transaction.Transaction\"I\n\x18\x44\x65leteTransactionRequest\x12-\n\x0btransaction\x18\x01 \x01(\x0b\x32\x18.transaction.Transaction\"\x18\n\x16ListTransactionRequest\"I\n\x18\x46inishTransactionRequest\x12-\n\x0btransaction\x18\x01 \x01(\x0b\x32\x18.transaction.Transaction2\xe4\x04\n\x03\x41PI\x12X\n\x10\x42\x61tchTransaction\x12$.transaction.BatchTransactionRequest\x1a\x1c.transaction.TransactionInfo\"\x00\x12T\n\x10StartTransaction\x12$.transaction.StartTransactionRequest\x1a\x18.transaction.Transaction\"\x00\x12\\\n\x12InspectTransaction\x12&.transaction.InspectTransactionRequest\x1a\x1c.transaction.TransactionInfo\"\x00\x12T\n\x11\x44\x65leteTransaction\x12%.transaction.DeleteTransactionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12W\n\x0fListTransaction\x12#.transaction.ListTransactionRequest\x1a\x1d.transaction.TransactionInfos\"\x00\x12Z\n\x11\x46inishTransaction\x12%.transaction.FinishTransactionRequest\x1a\x1c.transaction.TransactionInfo\"\x00\x12\x44\n\tDeleteAll\x12\x1d.transaction.DeleteAllRequest\x1a\x16.google.protobuf.Empty\"\x00\x42\x37Z5github.com/pachyderm/pachyderm/src/client/transactionb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,client_dot_pfs_dot_pfs__pb2.DESCRIPTOR,client_dot_pps_dot_pps__pb2.DESCRIPTOR,])




_DELETEALLREQUEST = _descriptor.Descriptor(
  name='DeleteAllRequest',
  full_name='transaction.DeleteAllRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=177,
)


_TRANSACTIONREQUEST = _descriptor.Descriptor(
  name='TransactionRequest',
  full_name='transaction.TransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create_repo', full_name='transaction.TransactionRequest.create_repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_repo', full_name='transaction.TransactionRequest.delete_repo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_commit', full_name='transaction.TransactionRequest.start_commit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finish_commit', full_name='transaction.TransactionRequest.finish_commit', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_commit', full_name='transaction.TransactionRequest.delete_commit', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_branch', full_name='transaction.TransactionRequest.create_branch', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_branch', full_name='transaction.TransactionRequest.delete_branch', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_job_state', full_name='transaction.TransactionRequest.update_job_state', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_pipeline', full_name='transaction.TransactionRequest.create_pipeline', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_all', full_name='transaction.TransactionRequest.delete_all', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=691,
)


_TRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='TransactionResponse',
  full_name='transaction.TransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='transaction.TransactionResponse.commit', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=693,
  serialized_end=743,
)


_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='transaction.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='transaction.Transaction.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=770,
)


_TRANSACTIONINFO = _descriptor.Descriptor(
  name='TransactionInfo',
  full_name='transaction.TransactionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='transaction.TransactionInfo.transaction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requests', full_name='transaction.TransactionInfo.requests', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='responses', full_name='transaction.TransactionInfo.responses', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='started', full_name='transaction.TransactionInfo.started', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=773,
  serialized_end=986,
)


_TRANSACTIONINFOS = _descriptor.Descriptor(
  name='TransactionInfos',
  full_name='transaction.TransactionInfos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_info', full_name='transaction.TransactionInfos.transaction_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=988,
  serialized_end=1062,
)


_BATCHTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='BatchTransactionRequest',
  full_name='transaction.BatchTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='transaction.BatchTransactionRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1064,
  serialized_end=1140,
)


_STARTTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='StartTransactionRequest',
  full_name='transaction.StartTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1142,
  serialized_end=1167,
)


_INSPECTTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='InspectTransactionRequest',
  full_name='transaction.InspectTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='transaction.InspectTransactionRequest.transaction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1169,
  serialized_end=1243,
)


_DELETETRANSACTIONREQUEST = _descriptor.Descriptor(
  name='DeleteTransactionRequest',
  full_name='transaction.DeleteTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='transaction.DeleteTransactionRequest.transaction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1245,
  serialized_end=1318,
)


_LISTTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='ListTransactionRequest',
  full_name='transaction.ListTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1320,
  serialized_end=1344,
)


_FINISHTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='FinishTransactionRequest',
  full_name='transaction.FinishTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction', full_name='transaction.FinishTransactionRequest.transaction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1346,
  serialized_end=1419,
)

_TRANSACTIONREQUEST.fields_by_name['create_repo'].message_type = client_dot_pfs_dot_pfs__pb2._CREATEREPOREQUEST
_TRANSACTIONREQUEST.fields_by_name['delete_repo'].message_type = client_dot_pfs_dot_pfs__pb2._DELETEREPOREQUEST
_TRANSACTIONREQUEST.fields_by_name['start_commit'].message_type = client_dot_pfs_dot_pfs__pb2._STARTCOMMITREQUEST
_TRANSACTIONREQUEST.fields_by_name['finish_commit'].message_type = client_dot_pfs_dot_pfs__pb2._FINISHCOMMITREQUEST
_TRANSACTIONREQUEST.fields_by_name['delete_commit'].message_type = client_dot_pfs_dot_pfs__pb2._DELETECOMMITREQUEST
_TRANSACTIONREQUEST.fields_by_name['create_branch'].message_type = client_dot_pfs_dot_pfs__pb2._CREATEBRANCHREQUEST
_TRANSACTIONREQUEST.fields_by_name['delete_branch'].message_type = client_dot_pfs_dot_pfs__pb2._DELETEBRANCHREQUEST
_TRANSACTIONREQUEST.fields_by_name['update_job_state'].message_type = client_dot_pps_dot_pps__pb2._UPDATEJOBSTATEREQUEST
_TRANSACTIONREQUEST.fields_by_name['create_pipeline'].message_type = client_dot_pps_dot_pps__pb2._CREATEPIPELINEREQUEST
_TRANSACTIONREQUEST.fields_by_name['delete_all'].message_type = _DELETEALLREQUEST
_TRANSACTIONRESPONSE.fields_by_name['commit'].message_type = client_dot_pfs_dot_pfs__pb2._COMMIT
_TRANSACTIONINFO.fields_by_name['transaction'].message_type = _TRANSACTION
_TRANSACTIONINFO.fields_by_name['requests'].message_type = _TRANSACTIONREQUEST
_TRANSACTIONINFO.fields_by_name['responses'].message_type = _TRANSACTIONRESPONSE
_TRANSACTIONINFO.fields_by_name['started'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSACTIONINFOS.fields_by_name['transaction_info'].message_type = _TRANSACTIONINFO
_BATCHTRANSACTIONREQUEST.fields_by_name['requests'].message_type = _TRANSACTIONREQUEST
_INSPECTTRANSACTIONREQUEST.fields_by_name['transaction'].message_type = _TRANSACTION
_DELETETRANSACTIONREQUEST.fields_by_name['transaction'].message_type = _TRANSACTION
_FINISHTRANSACTIONREQUEST.fields_by_name['transaction'].message_type = _TRANSACTION
DESCRIPTOR.message_types_by_name['DeleteAllRequest'] = _DELETEALLREQUEST
DESCRIPTOR.message_types_by_name['TransactionRequest'] = _TRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['TransactionResponse'] = _TRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
DESCRIPTOR.message_types_by_name['TransactionInfo'] = _TRANSACTIONINFO
DESCRIPTOR.message_types_by_name['TransactionInfos'] = _TRANSACTIONINFOS
DESCRIPTOR.message_types_by_name['BatchTransactionRequest'] = _BATCHTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['StartTransactionRequest'] = _STARTTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['InspectTransactionRequest'] = _INSPECTTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteTransactionRequest'] = _DELETETRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['ListTransactionRequest'] = _LISTTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['FinishTransactionRequest'] = _FINISHTRANSACTIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeleteAllRequest = _reflection.GeneratedProtocolMessageType('DeleteAllRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALLREQUEST,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.DeleteAllRequest)
  })
_sym_db.RegisterMessage(DeleteAllRequest)

TransactionRequest = _reflection.GeneratedProtocolMessageType('TransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONREQUEST,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.TransactionRequest)
  })
_sym_db.RegisterMessage(TransactionRequest)

TransactionResponse = _reflection.GeneratedProtocolMessageType('TransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONRESPONSE,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.TransactionResponse)
  })
_sym_db.RegisterMessage(TransactionResponse)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTION,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.Transaction)
  })
_sym_db.RegisterMessage(Transaction)

TransactionInfo = _reflection.GeneratedProtocolMessageType('TransactionInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONINFO,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.TransactionInfo)
  })
_sym_db.RegisterMessage(TransactionInfo)

TransactionInfos = _reflection.GeneratedProtocolMessageType('TransactionInfos', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONINFOS,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.TransactionInfos)
  })
_sym_db.RegisterMessage(TransactionInfos)

BatchTransactionRequest = _reflection.GeneratedProtocolMessageType('BatchTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHTRANSACTIONREQUEST,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.BatchTransactionRequest)
  })
_sym_db.RegisterMessage(BatchTransactionRequest)

StartTransactionRequest = _reflection.GeneratedProtocolMessageType('StartTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTTRANSACTIONREQUEST,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.StartTransactionRequest)
  })
_sym_db.RegisterMessage(StartTransactionRequest)

InspectTransactionRequest = _reflection.GeneratedProtocolMessageType('InspectTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTTRANSACTIONREQUEST,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.InspectTransactionRequest)
  })
_sym_db.RegisterMessage(InspectTransactionRequest)

DeleteTransactionRequest = _reflection.GeneratedProtocolMessageType('DeleteTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETRANSACTIONREQUEST,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.DeleteTransactionRequest)
  })
_sym_db.RegisterMessage(DeleteTransactionRequest)

ListTransactionRequest = _reflection.GeneratedProtocolMessageType('ListTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRANSACTIONREQUEST,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.ListTransactionRequest)
  })
_sym_db.RegisterMessage(ListTransactionRequest)

FinishTransactionRequest = _reflection.GeneratedProtocolMessageType('FinishTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINISHTRANSACTIONREQUEST,
  '__module__' : 'client.transaction.transaction_pb2'
  # @@protoc_insertion_point(class_scope:transaction.FinishTransactionRequest)
  })
_sym_db.RegisterMessage(FinishTransactionRequest)


DESCRIPTOR._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='transaction.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1422,
  serialized_end=2034,
  methods=[
  _descriptor.MethodDescriptor(
    name='BatchTransaction',
    full_name='transaction.API.BatchTransaction',
    index=0,
    containing_service=None,
    input_type=_BATCHTRANSACTIONREQUEST,
    output_type=_TRANSACTIONINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StartTransaction',
    full_name='transaction.API.StartTransaction',
    index=1,
    containing_service=None,
    input_type=_STARTTRANSACTIONREQUEST,
    output_type=_TRANSACTION,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InspectTransaction',
    full_name='transaction.API.InspectTransaction',
    index=2,
    containing_service=None,
    input_type=_INSPECTTRANSACTIONREQUEST,
    output_type=_TRANSACTIONINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTransaction',
    full_name='transaction.API.DeleteTransaction',
    index=3,
    containing_service=None,
    input_type=_DELETETRANSACTIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListTransaction',
    full_name='transaction.API.ListTransaction',
    index=4,
    containing_service=None,
    input_type=_LISTTRANSACTIONREQUEST,
    output_type=_TRANSACTIONINFOS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FinishTransaction',
    full_name='transaction.API.FinishTransaction',
    index=5,
    containing_service=None,
    input_type=_FINISHTRANSACTIONREQUEST,
    output_type=_TRANSACTIONINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='transaction.API.DeleteAll',
    index=6,
    containing_service=None,
    input_type=_DELETEALLREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from python_pachyderm.proto.pps import pps_pb2 as client_dot_pps_dot_pps__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class APIStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateJob = channel.unary_unary(
        '/pps.API/CreateJob',
        request_serializer=client_dot_pps_dot_pps__pb2.CreateJobRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.Job.FromString,
        )
    self.InspectJob = channel.unary_unary(
        '/pps.API/InspectJob',
        request_serializer=client_dot_pps_dot_pps__pb2.InspectJobRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.JobInfo.FromString,
        )
    self.ListJob = channel.unary_unary(
        '/pps.API/ListJob',
        request_serializer=client_dot_pps_dot_pps__pb2.ListJobRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.JobInfos.FromString,
        )
    self.ListJobStream = channel.unary_stream(
        '/pps.API/ListJobStream',
        request_serializer=client_dot_pps_dot_pps__pb2.ListJobRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.JobInfo.FromString,
        )
    self.FlushJob = channel.unary_stream(
        '/pps.API/FlushJob',
        request_serializer=client_dot_pps_dot_pps__pb2.FlushJobRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.JobInfo.FromString,
        )
    self.DeleteJob = channel.unary_unary(
        '/pps.API/DeleteJob',
        request_serializer=client_dot_pps_dot_pps__pb2.DeleteJobRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.StopJob = channel.unary_unary(
        '/pps.API/StopJob',
        request_serializer=client_dot_pps_dot_pps__pb2.StopJobRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.InspectDatum = channel.unary_unary(
        '/pps.API/InspectDatum',
        request_serializer=client_dot_pps_dot_pps__pb2.InspectDatumRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.DatumInfo.FromString,
        )
    self.ListDatum = channel.unary_unary(
        '/pps.API/ListDatum',
        request_serializer=client_dot_pps_dot_pps__pb2.ListDatumRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.ListDatumResponse.FromString,
        )
    self.ListDatumStream = channel.unary_stream(
        '/pps.API/ListDatumStream',
        request_serializer=client_dot_pps_dot_pps__pb2.ListDatumRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.ListDatumStreamResponse.FromString,
        )
    self.RestartDatum = channel.unary_unary(
        '/pps.API/RestartDatum',
        request_serializer=client_dot_pps_dot_pps__pb2.RestartDatumRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.CreatePipeline = channel.unary_unary(
        '/pps.API/CreatePipeline',
        request_serializer=client_dot_pps_dot_pps__pb2.CreatePipelineRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.InspectPipeline = channel.unary_unary(
        '/pps.API/InspectPipeline',
        request_serializer=client_dot_pps_dot_pps__pb2.InspectPipelineRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.PipelineInfo.FromString,
        )
    self.ListPipeline = channel.unary_unary(
        '/pps.API/ListPipeline',
        request_serializer=client_dot_pps_dot_pps__pb2.ListPipelineRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.PipelineInfos.FromString,
        )
    self.DeletePipeline = channel.unary_unary(
        '/pps.API/DeletePipeline',
        request_serializer=client_dot_pps_dot_pps__pb2.DeletePipelineRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.StartPipeline = channel.unary_unary(
        '/pps.API/StartPipeline',
        request_serializer=client_dot_pps_dot_pps__pb2.StartPipelineRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.StopPipeline = channel.unary_unary(
        '/pps.API/StopPipeline',
        request_serializer=client_dot_pps_dot_pps__pb2.StopPipelineRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.RunPipeline = channel.unary_unary(
        '/pps.API/RunPipeline',
        request_serializer=client_dot_pps_dot_pps__pb2.RunPipelineRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.RunCron = channel.unary_unary(
        '/pps.API/RunCron',
        request_serializer=client_dot_pps_dot_pps__pb2.RunCronRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.CreateSecret = channel.unary_unary(
        '/pps.API/CreateSecret',
        request_serializer=client_dot_pps_dot_pps__pb2.CreateSecretRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.DeleteSecret = channel.unary_unary(
        '/pps.API/DeleteSecret',
        request_serializer=client_dot_pps_dot_pps__pb2.DeleteSecretRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.ListSecret = channel.unary_unary(
        '/pps.API/ListSecret',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.SecretInfos.FromString,
        )
    self.InspectSecret = channel.unary_unary(
        '/pps.API/InspectSecret',
        request_serializer=client_dot_pps_dot_pps__pb2.InspectSecretRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.SecretInfo.FromString,
        )
    self.DeleteAll = channel.unary_unary(
        '/pps.API/DeleteAll',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.GetLogs = channel.unary_stream(
        '/pps.API/GetLogs',
        request_serializer=client_dot_pps_dot_pps__pb2.GetLogsRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.LogMessage.FromString,
        )
    self.GarbageCollect = channel.unary_unary(
        '/pps.API/GarbageCollect',
        request_serializer=client_dot_pps_dot_pps__pb2.GarbageCollectRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.GarbageCollectResponse.FromString,
        )
    self.ActivateAuth = channel.unary_unary(
        '/pps.API/ActivateAuth',
        request_serializer=client_dot_pps_dot_pps__pb2.ActivateAuthRequest.SerializeToString,
        response_deserializer=client_dot_pps_dot_pps__pb2.ActivateAuthResponse.FromString,
        )
    self.UpdateJobState = channel.unary_unary(
        '/pps.API/UpdateJobState',
        request_serializer=client_dot_pps_dot_pps__pb2.UpdateJobStateRequest.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class APIServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateJob(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InspectJob(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListJob(self, request, context):
    """ListJob returns information about current and past Pachyderm jobs. This is
    deprecated in favor of ListJobStream
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListJobStream(self, request, context):
    """ListJobStream returns information about current and past Pachyderm jobs.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FlushJob(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteJob(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StopJob(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InspectDatum(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListDatum(self, request, context):
    """ListDatum returns information about each datum fed to a Pachyderm job. This
    is deprecated in favor of ListDatumStream
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListDatumStream(self, request, context):
    """ListDatumStream returns information about each datum fed to a Pachyderm job
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RestartDatum(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreatePipeline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InspectPipeline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListPipeline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeletePipeline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StartPipeline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StopPipeline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RunPipeline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RunCron(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateSecret(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteSecret(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListSecret(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InspectSecret(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAll(self, request, context):
    """DeleteAll deletes everything
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetLogs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GarbageCollect(self, request, context):
    """Garbage collection
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ActivateAuth(self, request, context):
    """An internal call that causes PPS to put itself into an auth-enabled state
    (all pipeline have tokens, correct permissions, etcd)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateJobState(self, request, context):
    """An internal call used to move a job from one state to another
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_APIServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateJob': grpc.unary_unary_rpc_method_handler(
          servicer.CreateJob,
          request_deserializer=client_dot_pps_dot_pps__pb2.CreateJobRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.Job.SerializeToString,
      ),
      'InspectJob': grpc.unary_unary_rpc_method_handler(
          servicer.InspectJob,
          request_deserializer=client_dot_pps_dot_pps__pb2.InspectJobRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.JobInfo.SerializeToString,
      ),
      'ListJob': grpc.unary_unary_rpc_method_handler(
          servicer.ListJob,
          request_deserializer=client_dot_pps_dot_pps__pb2.ListJobRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.JobInfos.SerializeToString,
      ),
      'ListJobStream': grpc.unary_stream_rpc_method_handler(
          servicer.ListJobStream,
          request_deserializer=client_dot_pps_dot_pps__pb2.ListJobRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.JobInfo.SerializeToString,
      ),
      'FlushJob': grpc.unary_stream_rpc_method_handler(
          servicer.FlushJob,
          request_deserializer=client_dot_pps_dot_pps__pb2.FlushJobRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.JobInfo.SerializeToString,
      ),
      'DeleteJob': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteJob,
          request_deserializer=client_dot_pps_dot_pps__pb2.DeleteJobRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'StopJob': grpc.unary_unary_rpc_method_handler(
          servicer.StopJob,
          request_deserializer=client_dot_pps_dot_pps__pb2.StopJobRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'InspectDatum': grpc.unary_unary_rpc_method_handler(
          servicer.InspectDatum,
          request_deserializer=client_dot_pps_dot_pps__pb2.InspectDatumRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.DatumInfo.SerializeToString,
      ),
      'ListDatum': grpc.unary_unary_rpc_method_handler(
          servicer.ListDatum,
          request_deserializer=client_dot_pps_dot_pps__pb2.ListDatumRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.ListDatumResponse.SerializeToString,
      ),
      'ListDatumStream': grpc.unary_stream_rpc_method_handler(
          servicer.ListDatumStream,
          request_deserializer=client_dot_pps_dot_pps__pb2.ListDatumRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.ListDatumStreamResponse.SerializeToString,
      ),
      'RestartDatum': grpc.unary_unary_rpc_method_handler(
          servicer.RestartDatum,
          request_deserializer=client_dot_pps_dot_pps__pb2.RestartDatumRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'CreatePipeline': grpc.unary_unary_rpc_method_handler(
          servicer.CreatePipeline,
          request_deserializer=client_dot_pps_dot_pps__pb2.CreatePipelineRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'InspectPipeline': grpc.unary_unary_rpc_method_handler(
          servicer.InspectPipeline,
          request_deserializer=client_dot_pps_dot_pps__pb2.InspectPipelineRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.PipelineInfo.SerializeToString,
      ),
      'ListPipeline': grpc.unary_unary_rpc_method_handler(
          servicer.ListPipeline,
          request_deserializer=client_dot_pps_dot_pps__pb2.ListPipelineRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.PipelineInfos.SerializeToString,
      ),
      'DeletePipeline': grpc.unary_unary_rpc_method_handler(
          servicer.DeletePipeline,
          request_deserializer=client_dot_pps_dot_pps__pb2.DeletePipelineRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'StartPipeline': grpc.unary_unary_rpc_method_handler(
          servicer.StartPipeline,
          request_deserializer=client_dot_pps_dot_pps__pb2.StartPipelineRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'StopPipeline': grpc.unary_unary_rpc_method_handler(
          servicer.StopPipeline,
          request_deserializer=client_dot_pps_dot_pps__pb2.StopPipelineRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'RunPipeline': grpc.unary_unary_rpc_method_handler(
          servicer.RunPipeline,
          request_deserializer=client_dot_pps_dot_pps__pb2.RunPipelineRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'RunCron': grpc.unary_unary_rpc_method_handler(
          servicer.RunCron,
          request_deserializer=client_dot_pps_dot_pps__pb2.RunCronRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'CreateSecret': grpc.unary_unary_rpc_method_handler(
          servicer.CreateSecret,
          request_deserializer=client_dot_pps_dot_pps__pb2.CreateSecretRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'DeleteSecret': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteSecret,
          request_deserializer=client_dot_pps_dot_pps__pb2.DeleteSecretRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'ListSecret': grpc.unary_unary_rpc_method_handler(
          servicer.ListSecret,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.SecretInfos.SerializeToString,
      ),
      'InspectSecret': grpc.unary_unary_rpc_method_handler(
          servicer.InspectSecret,
          request_deserializer=client_dot_pps_dot_pps__pb2.InspectSecretRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.SecretInfo.SerializeToString,
      ),
      'DeleteAll': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAll,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'GetLogs': grpc.unary_stream_rpc_method_handler(
          servicer.GetLogs,
          request_deserializer=client_dot_pps_dot_pps__pb2.GetLogsRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.LogMessage.SerializeToString,
      ),
      'GarbageCollect': grpc.unary_unary_rpc_method_handler(
          servicer.GarbageCollect,
          request_deserializer=client_dot_pps_dot_pps__pb2.GarbageCollectRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.GarbageCollectResponse.SerializeToString,
      ),
      'ActivateAuth': grpc.unary_unary_rpc_method_handler(
          servicer.ActivateAuth,
          request_deserializer=client_dot_pps_dot_pps__pb2.ActivateAuthRequest.FromString,
          response_serializer=client_dot_pps_dot_pps__pb2.ActivateAuthResponse.SerializeToString,
      ),
      'UpdateJobState': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateJobState,
          request_deserializer=client_dot_pps_dot_pps__pb2.UpdateJobStateRequest.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'pps.API', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client/debug/debug.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from python_pachyderm.proto.pps import pps_pb2 as client_dot_pps_dot_pps__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='client/debug/debug.proto',
  package='debug',
  syntax='proto3',
  serialized_options=b'Z/github.com/pachyderm/pachyderm/src/client/debug',
  serialized_pb=b'\n\x18\x63lient/debug/debug.proto\x12\x05\x64\x65\x62ug\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x14\x63lient/pps/pps.proto\"P\n\x0eProfileRequest\x12\x1f\n\x07profile\x18\x01 \x01(\x0b\x32\x0e.debug.Profile\x12\x1d\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\r.debug.Filter\"D\n\x07Profile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"g\n\x06\x46ilter\x12\x0f\n\x05pachd\x18\x01 \x01(\x08H\x00\x12!\n\x08pipeline\x18\x02 \x01(\x0b\x32\r.pps.PipelineH\x00\x12\x1f\n\x06worker\x18\x03 \x01(\x0b\x32\r.debug.WorkerH\x00\x42\x08\n\x06\x66ilter\")\n\x06Worker\x12\x0b\n\x03pod\x18\x01 \x01(\t\x12\x12\n\nredirected\x18\x02 \x01(\x08\".\n\rBinaryRequest\x12\x1d\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\r.debug.Filter\";\n\x0b\x44umpRequest\x12\x1d\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\r.debug.Filter\x12\r\n\x05limit\x18\x02 \x01(\x03\x32\xc8\x01\n\x05\x44\x65\x62ug\x12\x41\n\x07Profile\x12\x15.debug.ProfileRequest\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12?\n\x06\x42inary\x12\x14.debug.BinaryRequest\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12;\n\x04\x44ump\x12\x12.debug.DumpRequest\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x42\x31Z/github.com/pachyderm/pachyderm/src/client/debugb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,client_dot_pps_dot_pps__pb2.DESCRIPTOR,])




_PROFILEREQUEST = _descriptor.Descriptor(
  name='ProfileRequest',
  full_name='debug.ProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile', full_name='debug.ProfileRequest.profile', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='debug.ProfileRequest.filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=201,
)


_PROFILE = _descriptor.Descriptor(
  name='Profile',
  full_name='debug.Profile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='debug.Profile.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='debug.Profile.duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=271,
)


_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='debug.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pachd', full_name='debug.Filter.pachd', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='debug.Filter.pipeline', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='worker', full_name='debug.Filter.worker', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='filter', full_name='debug.Filter.filter',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=273,
  serialized_end=376,
)


_WORKER = _descriptor.Descriptor(
  name='Worker',
  full_name='debug.Worker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pod', full_name='debug.Worker.pod', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redirected', full_name='debug.Worker.redirected', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=419,
)


_BINARYREQUEST = _descriptor.Descriptor(
  name='BinaryRequest',
  full_name='debug.BinaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='debug.BinaryRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=467,
)


_DUMPREQUEST = _descriptor.Descriptor(
  name='DumpRequest',
  full_name='debug.DumpRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='debug.DumpRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='debug.DumpRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=528,
)

_PROFILEREQUEST.fields_by_name['profile'].message_type = _PROFILE
_PROFILEREQUEST.fields_by_name['filter'].message_type = _FILTER
_PROFILE.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FILTER.fields_by_name['pipeline'].message_type = client_dot_pps_dot_pps__pb2._PIPELINE
_FILTER.fields_by_name['worker'].message_type = _WORKER
_FILTER.oneofs_by_name['filter'].fields.append(
  _FILTER.fields_by_name['pachd'])
_FILTER.fields_by_name['pachd'].containing_oneof = _FILTER.oneofs_by_name['filter']
_FILTER.oneofs_by_name['filter'].fields.append(
  _FILTER.fields_by_name['pipeline'])
_FILTER.fields_by_name['pipeline'].containing_oneof = _FILTER.oneofs_by_name['filter']
_FILTER.oneofs_by_name['filter'].fields.append(
  _FILTER.fields_by_name['worker'])
_FILTER.fields_by_name['worker'].containing_oneof = _FILTER.oneofs_by_name['filter']
_BINARYREQUEST.fields_by_name['filter'].message_type = _FILTER
_DUMPREQUEST.fields_by_name['filter'].message_type = _FILTER
DESCRIPTOR.message_types_by_name['ProfileRequest'] = _PROFILEREQUEST
DESCRIPTOR.message_types_by_name['Profile'] = _PROFILE
DESCRIPTOR.message_types_by_name['Filter'] = _FILTER
DESCRIPTOR.message_types_by_name['Worker'] = _WORKER
DESCRIPTOR.message_types_by_name['BinaryRequest'] = _BINARYREQUEST
DESCRIPTOR.message_types_by_name['DumpRequest'] = _DUMPREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProfileRequest = _reflection.GeneratedProtocolMessageType('ProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROFILEREQUEST,
  '__module__' : 'client.debug.debug_pb2'
  # @@protoc_insertion_point(class_scope:debug.ProfileRequest)
  })
_sym_db.RegisterMessage(ProfileRequest)

Profile = _reflection.GeneratedProtocolMessageType('Profile', (_message.Message,), {
  'DESCRIPTOR' : _PROFILE,
  '__module__' : 'client.debug.debug_pb2'
  # @@protoc_insertion_point(class_scope:debug.Profile)
  })
_sym_db.RegisterMessage(Profile)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'client.debug.debug_pb2'
  # @@protoc_insertion_point(class_scope:debug.Filter)
  })
_sym_db.RegisterMessage(Filter)

Worker = _reflection.GeneratedProtocolMessageType('Worker', (_message.Message,), {
  'DESCRIPTOR' : _WORKER,
  '__module__' : 'client.debug.debug_pb2'
  # @@protoc_insertion_point(class_scope:debug.Worker)
  })
_sym_db.RegisterMessage(Worker)

BinaryRequest = _reflection.GeneratedProtocolMessageType('BinaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYREQUEST,
  '__module__' : 'client.debug.debug_pb2'
  # @@protoc_insertion_point(class_scope:debug.BinaryRequest)
  })
_sym_db.RegisterMessage(BinaryRequest)

DumpRequest = _reflection.GeneratedProtocolMessageType('DumpRequest', (_message.Message,), {
  'DESCRIPTOR' : _DUMPREQUEST,
  '__module__' : 'client.debug.debug_pb2'
  # @@protoc_insertion_point(class_scope:debug.DumpRequest)
  })
_sym_db.RegisterMessage(DumpRequest)


DESCRIPTOR._options = None

_DEBUG = _descriptor.ServiceDescriptor(
  name='Debug',
  full_name='debug.Debug',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=531,
  serialized_end=731,
  methods=[
  _descriptor.MethodDescriptor(
    name='Profile',
    full_name='debug.Debug.Profile',
    index=0,
    containing_service=None,
    input_type=_PROFILEREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Binary',
    full_name='debug.Debug.Binary',
    index=1,
    containing_service=None,
    input_type=_BINARYREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Dump',
    full_name='debug.Debug.Dump',
    index=2,
    containing_service=None,
    input_type=_DUMPREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEBUG)

DESCRIPTOR.services_by_name['Debug'] = _DEBUG

# @@protoc_insertion_point(module_scope)



from python_pachyderm.service import Service
from python_pachyderm.proto.version.versionpb import version_pb2_grpc as version_grpc


class VersionMixin:
    def get_remote_version(self):
        return self._req(
            Service.VERSION,
            "GetVersion",
            req=version_grpc.google_dot_protobuf_dot_empty__pb2.Empty(),
        )



#!/usr/bin/env python

import json
from glob import glob
from os.path import basename
from os.path import dirname
from os.path import join
from os.path import splitext

from setuptools import find_packages
from setuptools import setup

with open(join(dirname(__file__), "README.md"), "r") as f:
    readme = f.read()

with open(join(dirname(__file__), "version.json"), "r") as f:
    j = json.load(f)
    version = j["python-pachyderm"]

with open(join(dirname(__file__), "src", "python_pachyderm", "version.py"), "w") as f:
    f.write("__version__ = '{}'\n".format(version))

setup(
    name="python-pachyderm",
    version=version,
    license="Apache 2.0",
    description="Python Pachyderm Client",
    long_description_content_type="text/markdown",
    long_description=readme,
    author="Joe Doliner",
    author_email="jdoliner@pachyderm.io",
    url="https://github.com/pachyderm/python-pachyderm",
    packages=find_packages("src"),
    package_dir={"": "src"},
    py_modules=[splitext(basename(path))[0] for path in glob("src/*.py")],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        # complete list: http://pypi.python.org/pypi?%3Aaction=list_classifiers
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    keywords=[
        "pachyderm",
    ],
    install_requires=[
        "protobuf>=3.11.2",
        "grpcio>=1.26.0",
    ],
    extras_require={
        "system_certs": ["certifi>=2019.11.28"],
        "DEV": [
            "black>=21.5b0",
            "flake8>=3.9.1",
            "pre-commit>=2.12.1",
            "pytest>=5.3.4",
            "tox>=3.23.1",
            "twine>=3.4.1",
        ],
    },
    test_suite="tests",
    setup_requires=["pytest-runner"],
    python_requires=">=3.6",
)



import io
import os
import tarfile
import contextlib


class SpoutManager:
    """
    A convenience context manager for creating spouts, allowing you to create
    spout code like:

    ```
    spout = SpoutManager()
    while True:
        with spout.commit() as commit:
            commit.put_file_from_bytes("foo", b"#")
        time.sleep(1.0)
    ```
    """

    def __init__(self, marker_filename=None, pfs_directory="/pfs"):
        """
        Creates a new spout manager.

        Params:

        * `marker_filename`: The name of the file for storing markers. If
        unspecified, marker-related operations will fail.
        * `pfs_directory`: The directory for PFS content. Usually this
        shouldn't be explicitly specified, unless the spout manager is being
        tested outside of a real Pachyderm pipeline.
        """

        self.marker_filename = marker_filename
        self.pfs_directory = pfs_directory
        self._pipe = open(os.path.join(self.pfs_directory, "out"), "wb")
        self._has_open_commit = False

    def close(self):
        self._pipe.close()

    @contextlib.contextmanager
    def marker(self):
        """
        Gets the marker file as a context manager.
        """

        if self.marker_filename is None:
            raise Exception("no marker filename set")
        with open(os.path.join(self.pfs_directory, self.marker_filename), "r") as f:
            yield f

    @contextlib.contextmanager
    def commit(self):
        """
        Opens a commit on the spout. When the context manager exits, any added
        files will be committed.
        """
        if self._has_open_commit:
            raise Exception("spout commit context manager already opened")
        spout_commit = SpoutCommit(self._pipe, marker_filename=self.marker_filename)
        self._has_open_commit = True
        try:
            yield spout_commit
        finally:
            spout_commit.close()
            self._has_open_commit = False


class SpoutCommit:
    """
    Represents a commit on a spout, permitting the addition of files.
    """

    def __init__(self, pipe, marker_filename=None):
        self._tarstream = tarfile.open(fileobj=pipe, mode="w|", encoding="utf-8")
        self.marker_filename = marker_filename

    def close(self):
        """Closes the commit"""
        self._tarstream.close()

    def put_file_from_fileobj(self, path, size, fileobj):
        """
        Adds a file to the spout from a file-like object.

        Params:

        * `path`: The path to the file in the spout.
        * `size`: The size of the file.
        * `fileobj`: The file-like object to add.
        """

        tar_info = tarfile.TarInfo(path)
        tar_info.size = size
        tar_info.mode = 0o600
        self._tarstream.addfile(tarinfo=tar_info, fileobj=fileobj)

    def put_file_from_bytes(self, path, bytes):
        """
        Adds a file to the spout from a bytestring.

        Params:

        * `path`: The path to the file in the spout.
        * `bytes`: The bytestring representing the file contents.
        """

        self.put_file_from_fileobj(path, len(bytes), io.BytesIO(bytes))

    def put_marker_from_fileobj(self, size, fileobj):
        """
        Writes to the marker file from a file-like object.

        Params:

        * `size`: The size of the file.
        * `fileobj`: The file-like object to add.
        """

        if self.marker_filename is None:
            raise Exception("no marker filename set")
        self.put_file_from_fileobj(self.marker_filename, size, fileobj)

    def put_marker_from_bytes(self, bytes):
        """
        Adds to the marker from a bytestring.

        Params:

        * `bytes`: The bytestring representing the file contents.
        """

        if self.marker_filename is None:
            raise Exception("no marker filename set")
        self.put_file_from_fileobj(self.marker_filename, len(bytes), io.BytesIO(bytes))



import os
from pathlib import Path

from .proto.pps.pps_pb2 import Transform, CreatePipelineRequest, BuildSpec

from google.protobuf import json_format

# Default script for running python code with wheels in a pipeline that was
# deployed with `create_python_pipeline`.
RUNNER_SCRIPT_WITH_WHEELS = """
#!/bin/sh
set -{set_args}

cd /pfs/{source_repo_name}
pip install /pfs/{build_pipeline_name}/*.whl
python main.py
"""

# Default script for running python code without wheels in a pipeline that was
# deployed with `create_python_pipeline`.
RUNNER_SCRIPT_WITHOUT_WHEELS = """
#!/bin/sh
set -{set_args}

cd /pfs/{source_repo_name}
python main.py
"""

# Default script for building python wheels for a pipeline that was deployed
# with `create_python_pipeline`.
BUILDER_SCRIPT = """
#!/bin/sh
set -{set_args}
python --version
pip --version

cd /pfs/{source_repo_name}
test -f requirements.txt && pip wheel -r requirements.txt -w /pfs/out
"""


def put_files(client, source_path, commit, dest_path, **kwargs):
    """
    Utility function for inserting files from the local `source_path`
    to pachyderm. Roughly equivalent to `pachctl put file [-r]`.

    Params:

    * `client`: The `Client` instance to use.
    * `source_path`: The file/directory to recursively insert content from.
    * `commit`: The `Commit` object to use for inserting files.
    * `dest_path`: The destination path in PFS.
    * `kwargs`: Keyword arguments to forward. See
    `PutFileClient.put_file_from_fileobj` for details.
    """

    with client.put_file_client() as pfc:
        if os.path.isfile(source_path):
            pfc.put_file_from_filepath(commit, dest_path, source_path, **kwargs)
        elif os.path.isdir(source_path):
            for root, _, filenames in os.walk(source_path):
                for filename in filenames:
                    source_filepath = os.path.join(root, filename)
                    dest_filepath = os.path.join(
                        dest_path, os.path.relpath(source_filepath, start=source_path)
                    )
                    pfc.put_file_from_filepath(
                        commit, dest_filepath, source_filepath, **kwargs
                    )
        else:
            raise Exception("Please provide an existing directory or file")


def create_python_pipeline(
    client,
    path,
    input=None,
    pipeline_name=None,
    image_pull_secrets=None,
    debug=None,
    env=None,
    secrets=None,
    image=None,
    update=False,
    **pipeline_kwargs
):
    """
    Utility function for creating (or updating) a pipeline specially built for
    executing python code that is stored locally at `path`.

    A normal pipeline creation process requires you to first build and push a
    container image with the source and dependencies baked in. As an alternative
    process, this function circumvents container image creation by using build
    step-enabled pipelines. See the pachyderm core docs for more info.

    If `path` references a directory, it should have:

    * A `main.py`, as the pipeline entry-point.
    * An optional `requirements.txt` that specifies pip requirements.

    Params:

    * `client`: The `Client` instance to use.
    * `path`: The directory containing the python pipeline source, or an
    individual python file.
    * `input`: An optional `Input` object specifying the pipeline input.
    * `pipeline_name`: An optional string specifying the pipeline name.
    Defaults to using the last directory name in `path`.
    * `image_pull_secrets`: An optional list of strings specifying the
    pipeline transform's image pull secrets, which are used for pulling images
    from a private registry. Defaults to `None`, in which case the public
    docker registry will be used. See the pipeline spec document for more
    details.
    * `debug`: An optional bool specifying whether debug logging should be
    enabled for the pipeline. Defaults to `False`.
    * `env`: An optional mapping of string keys to string values specifying
    custom environment variables.
    * `secrets`: An optional list of `Secret` objects for secret environment
    variables.
    * `image`: An optional string specifying the docker image to use for the
    pipeline. Defaults to using pachyderm's official python language builder.
    * `update`: Whether to act as an upsert.
    * `pipeline_kwargs`: Keyword arguments to forward to `create_pipeline`.
    """

    return client.create_pipeline(
        pipeline_name or Path(path).name,
        Transform(
            image_pull_secrets=image_pull_secrets,
            debug=debug,
            env=env,
            secrets=secrets,
            build=BuildSpec(path=path, image=image)
            if image
            else BuildSpec(path=path, language="python"),
        ),
        update=update,
        input=input,
        **pipeline_kwargs
    )


def parse_json_pipeline_spec(j):
    """
    Parses a string of JSON into a `CreatePipelineRequest` protobuf.
    """
    return json_format.Parse(j, CreatePipelineRequest())


def parse_dict_pipeline_spec(d):
    """
    Parses a dict of serialized JSON into a `CreatePipelineRequest` protobuf.
    """
    return json_format.ParseDict(d, CreatePipelineRequest())



#!/usr/bin/env python

"""Tests for versioning-related functionality."""

import json
from os.path import join
from os.path import dirname

import python_pachyderm


def test_local_version():
    with open(join(dirname(dirname(__file__)), "version.json"), "r") as f:
        j = json.load(f)
        version = j["python-pachyderm"]
    assert python_pachyderm.__version__ == version


def test_remote_version():
    version_pb = python_pachyderm.Client().get_remote_version()
    assert isinstance(version_pb, python_pachyderm.Version)
